Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `RDFCalendar`: Conversion of iCalendar/vCard resources to RDF information.
  - `Format`: Constants for parsing and writing.
  - `FormatWriters`: Format writer classes.
  - `Parsers`: Conversion of iCalendar files to and from RDF representations.
  - `Store`: Storage of nodes according to RDFCalendar conventions.
  - `Writers`: Writer classes.

## Class Hierarchy

- `RDFCalendar.FormatWriters.iCalendarWriter`: An iCalendar writer class.
- `RDFCalendar.Parsers.DOMParser`: A parser which reads resource definitions from DOM documents.
- `RDFCalendar.Parsers.Reader`: A simple class wrapping a file, providing simple pushback capabilities.
- `RDFCalendar.Parsers.iCalendarParser`: An iCalendar parser.
- `RDFFormats.FormatWriters.DOMWriter`: A DOM document writer.
  - `RDFCalendar.FormatWriters.DOMWriter`: A DOM document writer.
- `RDFFormats.Store.AbstractHandler`: WebOrganiser-compatible handler methods.
  - `RDFFormats.Store.Store`: A store class providing, in each instance, a wrapper around an underlying store, convenience attributes based on namespaces from the Format module and node types from the underlying store implementation, and a selection of higher-level operations relevant to parsing and writing.
    - `RDFCalendar.Store.Store`: A wrapper around a data store, providing convenient access for parsers and writers.
- `RDFFormats.Store.AbstractStore`: The interface employed by the RDFCalendar.Parsers classes.
  - `RDFCalendar.Store.FreeBusyRequest`: A record of free/busy request information.
  - `RDFFormats.Store.Store`: A store class providing, in each instance, a wrapper around an underlying store, convenience attributes based on namespaces from the Format module and node types from the underlying store implementation, and a selection of higher-level operations relevant to parsing and writing.
    - `RDFCalendar.Store.Store`: A wrapper around a data store, providing convenient access for parsers and writers.
- `RDFFormats.Writers.Writer`: A writer class which, acting as a visitor on nodes in a store, employs a format writer in order to produce actual output.
  - `RDFCalendar.Writers.Writer`
- `exceptions.Exception`: Common base class for all exceptions.
  - `RDFCalendar.Parsers.DuplicateResourceError`

Generated by Epydoc 2.1 on Tue Mar 27 01:15:38 2007 | http://epydoc.sf.net